@@ -44,11 +44,13 @@ class SAApiTestCase(test.ConfiguredBaseTestCase):
         _saved_torrent = self.dbconn.save(torrent)
         self.assertIsInstance(_saved_torrent, api_model.Torrent)
 
-        self.assertNotEqual(torrent, _saved_torrent)
+        self.assertIsNone(torrent.created_at)
+        self.assertIsNotNone(_saved_torrent.created_at)
 
         _saved_torrent.state = 'active'
         torrent = self.dbconn.save(_saved_torrent)
-        self.assertNotEqual(torrent, _saved_torrent)
+        self.assertIsNotNone(torrent.updated_at)
+        self.assertIsNone(_saved_torrent.updated_at)
 
     def test_bulk_create(self):
 
