@@ -1,3 +1,4 @@
+
 from seedbox.db import exception
 from seedbox.tests import test
 
@@ -6,8 +7,8 @@ class DbExceptionTest(test.BaseTestCase):
 
     def test_db_error(self):
 
-        def gen_error(err):
-            raise exception.DBError(err)
+        def gen_error(an_error):
+            raise exception.DBError(an_error)
 
         err = self.assertRaises(exception.DBError,
                                 gen_error,
@@ -16,8 +17,8 @@ class DbExceptionTest(test.BaseTestCase):
 
     def test_multiple_results_error(self):
 
-        def gen_error(err):
-            raise exception.MultipleResultsFound(err)
+        def gen_error(an_error):
+            raise exception.MultipleResultsFound(an_error)
 
         err = self.assertRaises(exception.MultipleResultsFound,
                                 gen_error,
@@ -26,8 +27,8 @@ class DbExceptionTest(test.BaseTestCase):
 
     def test_no_results_error(self):
 
-        def gen_error(err):
-            raise exception.NoResultFound(err)
+        def gen_error(an_error):
+            raise exception.NoResultFound(an_error)
 
         err = self.assertRaises(exception.NoResultFound,
                                 gen_error,
@@ -36,8 +37,8 @@ class DbExceptionTest(test.BaseTestCase):
 
     def test_db_migration_error(self):
 
-        def gen_error(err):
-            raise exception.DbMigrationError(err)
+        def gen_error(an_error):
+            raise exception.DbMigrationError(an_error)
 
         err = self.assertRaises(exception.DbMigrationError,
                                 gen_error,
